searchData={"items":[{"type":"module","title":"EctoEmail","doc":"An `Ecto.Type` for email addresses, using the\n[`:email_validator`](https://github.com/rbkmoney/email_validator) library\nfor validations.","ref":"EctoEmail.html"},{"type":"module","title":"Usage - EctoEmail","doc":"When creating an email field, the underline column  should be specified\nas a `:string` or a `:text`.","ref":"EctoEmail.html#module-usage"},{"type":"module","title":"Migration - EctoEmail","doc":"``` elixir\ndefmodule Core.Repo.Migrations.CreatePeople do\n  use Ecto.Migration\n\n  def change do\n    create table(:people) do\n      add :email_address, :string, null: false\n      timestamps()\n    end\n  end\nend\n```","ref":"EctoEmail.html#module-migration"},{"type":"module","title":"Schema - EctoEmail","doc":"The schema should specify the field as an `EctoEmail`. This will\napply automatic validations to the field, though when accessing\nrelevant structs the data will be returned as `String` values.\n\n``` elixir\ndefmodule Schema.Person do\n  use Ecto.Schema\n  import Ecto.Changeset\n\n  schema \"people\" do\n    field :email_address, EctoEmail\n  end\n\n  def changeset(data \\ %__MODULE__{}, attrs) do\n    data\n    |> cast(Map.new(attrs), ~w[email_address]a)\n  end\nend\n```","ref":"EctoEmail.html#module-schema"},{"type":"module","title":"Changesets - EctoEmail","doc":"Ecto changesets using the `Ecto.Enum` type will automatically validate\nthe format of values.\n\n``` elixir\niex> assert Schema.Person.changeset(email_address: \"a@b.com\").valid?\niex> assert changeset = Schema.Person.changeset(email_address: \"a.at.b.com\")\niex> refute changeset.valid?\niex> assert [email_address: {\"malformed email address\", _}] = changeset.errors\n```","ref":"EctoEmail.html#module-changesets"},{"type":"function","title":"EctoEmail.cast/1","doc":"Callback implementation for `c:Ecto.Type.cast/1`.\n\nCasts external input to a string, while validating that the format of the\ncontents.\n\n``` elixir\niex> EctoEmail.cast(\"a@b.com\")\n{:ok, \"a@b.com\"}\niex> EctoEmail.cast(\"a+b@c.com\")\n{:ok, \"a+b@c.com\"}\n\niex> EctoEmail.cast(\"a.c.com\")\n{:error, message: \"malformed email address\"}\niex> EctoEmail.cast(\"12\")\n{:error, message: \"malformed email address\"}\niex> EctoEmail.cast(12)\n{:error, message: \"invalid email address\"}\n\niex> assert %Ecto.Changeset{valid?: true} = Schema.Person.changeset(email_address: \"a@b.com\")\niex> assert %Ecto.Changeset{valid?: false} = Schema.Person.changeset(email_address: \"a.b.com\")\n```","ref":"EctoEmail.html#cast/1"},{"type":"function","title":"EctoEmail.dump/1","doc":"Callback implementation for `c:Ecto.Type.dump/1`","ref":"EctoEmail.html#dump/1"},{"type":"function","title":"EctoEmail.embed_as/1","doc":"","ref":"EctoEmail.html#embed_as/1"},{"type":"function","title":"EctoEmail.equal?/2","doc":"Callback implementation for `c:Ecto.Type.equal?/2`.\n\n``` elixir\niex> assert EctoEmail.equal?(\"a@b.com\", \"a@b.com\")\niex> refute EctoEmail.equal?(\"a@b.com\", \"a@c.com\")\n```","ref":"EctoEmail.html#equal?/2"},{"type":"function","title":"EctoEmail.load/1","doc":"Callback implementation for `c:Ecto.Type.load/1`","ref":"EctoEmail.html#load/1"},{"type":"function","title":"EctoEmail.type/0","doc":"Callback implementation for `c:Ecto.Type.type/0`.\n\nEmail address fields using `EctoEmail` should use a database column type\ncapable of working with `:string` Ecto type. `:string`, `:text`, or `:citext`\nare examples of column types useable in migrations.","ref":"EctoEmail.html#type/0"},{"type":"extras","title":"LICENSE","doc":"Copyright 2024 [synchronal.dev](https://github.com/synchronal)\n\nPermission is hereby granted, free of charge, to any person obtaining a\ncopy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be included\nin all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS\nOR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.\nIN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY\nCLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,\nTORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE\nSOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"CHANGELOG","doc":"","ref":"changelog.html"},{"type":"extras","title":"Change log - CHANGELOG","doc":"","ref":"changelog.html#change-log"},{"type":"extras","title":"2.0.0 - CHANGELOG","doc":"- Email addresses with different cases are considered equal.\n- **Breaking change:** Use `EctoEmail` instead of `Ecto.Email`.","ref":"changelog.html#2-0-0"},{"type":"extras","title":"1.0.0 - CHANGELOG","doc":"- Initial release.\n- Adds `Ecto.Email` type for schemas with email address fields.","ref":"changelog.html#1-0-0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,51,46,48]}}